package cn.bunny.dao.vo.financial.user;

import cn.bunny.dao.common.vo.BaseVo;
import com.alibaba.fastjson2.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.fasterxml.jackson.datatype.jsr310.deser.LocalDateTimeDeserializer;
import com.fasterxml.jackson.datatype.jsr310.ser.LocalDateTimeSerializer;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.*;

import java.math.BigDecimal;
import java.time.LocalDateTime;

@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Schema(name = "BillVo对象", title = "账单信息返回内容", description = "账单信息返回内容")
public class BillUserVo extends BaseVo {

    @Schema(name = "username", title = "类型：1 - 收入，-1 - 支出")
    private Byte type;

    @Schema(name = "amount", title = "金额")
    private BigDecimal amount;

    @Schema(name = "description", title = "描述")
    private String description;

    @Schema(name = "transactionDate", title = "交易日期")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonSerialize(using = LocalDateTimeSerializer.class)
    @JsonDeserialize(using = LocalDateTimeDeserializer.class)
    private LocalDateTime transactionDate;

    @Schema(name = "categoryId", title = "分类Id")
    @JsonFormat(shape = JsonFormat.Shape.STRING)
    @JSONField(serializeUsing = ToStringSerializer.class)
    private String categoryId;

    @Schema(name = "categoryName", title = "类别分类")
    private String categoryName;

}
