package cn.bunny.services.service.financial;

import cn.bunny.dao.dto.financial.category.admin.CategoryAddDto;
import cn.bunny.dao.dto.financial.category.admin.CategoryDto;
import cn.bunny.dao.dto.financial.category.admin.CategoryUpdateDto;
import cn.bunny.dao.dto.financial.category.user.CategoryUserAddDto;
import cn.bunny.dao.dto.financial.category.user.CategoryUserDto;
import cn.bunny.dao.dto.financial.category.user.CategoryUserUpdateDto;
import cn.bunny.dao.entity.financial.Category;
import cn.bunny.dao.pojo.result.PageResult;
import cn.bunny.dao.vo.financial.admin.CategoryVo;
import cn.bunny.dao.vo.financial.user.CategoryUserVo;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import jakarta.validation.Valid;

import java.util.List;

/**
 * <p>
 * 分类信息 服务类
 * </p>
 *
 * @author Bunny
 * @since 2024-11-08 10:29:58
 */
public interface CategoryService extends IService<Category> {

    /**
     * * 用户分类分页查询分类信息
     *
     * @return 分类信息返回列表
     */
    PageResult<CategoryUserVo> getCategoryUserList(Page<Category> pageParams, CategoryUserDto dto);

    /**
     * * 用戶分类添加分类信息
     *
     * @param dto 添加表单
     */
    void addCategoryUser(@Valid CategoryUserAddDto dto);

    /**
     * * 用户分类更新分类信息
     *
     * @param dto 更新表单
     */
    void updateCategoryUser(@Valid CategoryUserUpdateDto dto);

    /**
     * * 用户分类删除分类信息|批量删除分类信息类型
     *
     * @param ids 删除id列表
     */
    void deleteCategoryUser(List<Long> ids);

    /**
     * 查询当前用户下所有的分类
     *
     * @return 当前用户分类返回列表
     */
    List<CategoryUserVo> getCategoryUserAllList();

    /**
     * * 获取分类信息列表
     *
     * @return 分类信息返回列表
     */
    PageResult<CategoryVo> getCategoryList(Page<Category> pageParams, CategoryDto dto);

    /**
     * * 添加分类信息
     *
     * @param dto 添加表单
     */
    void addCategory(@Valid CategoryAddDto dto);

    /**
     * * 更新分类信息
     *
     * @param dto 更新表单
     */
    void updateCategory(@Valid CategoryUpdateDto dto);

    /**
     * * 删除|批量删除分类信息类型
     *
     * @param ids 删除id列表
     */
    void deleteCategory(List<Long> ids);
}
