package cn.bunny.services.service.financial.impl;

import cn.bunny.common.service.context.BaseContext;
import cn.bunny.dao.dto.financial.bill.user.BillUserAddDto;
import cn.bunny.dao.dto.financial.bill.user.BillUserDto;
import cn.bunny.dao.dto.financial.bill.user.BillUserUpdateDto;
import cn.bunny.dao.entity.financial.Bill;
import cn.bunny.dao.pojo.result.PageResult;
import cn.bunny.dao.vo.financial.user.BillUserVo;
import cn.bunny.services.mapper.financial.BillMapper;
import cn.bunny.services.service.financial.BillService;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import jakarta.validation.Valid;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 账单信息 服务实现类
 * </p>
 *
 * @author Bunny
 * @since 2024-11-07 16:49:19
 */
@Service
public class BillServiceImpl extends ServiceImpl<BillMapper, Bill> implements BillService {

    /**
     * * 账单信息 服务实现类
     *
     * @param pageParams 账单信息分页查询page对象
     * @param dto        账单信息分页查询对象
     * @return 查询分页账单信息返回对象
     */
    @Override
    public PageResult<BillUserVo> getBillList(Page<Bill> pageParams, BillUserDto dto) {
        // 需要根据当前用户去查询
        Long userId = BaseContext.getUserId();

        // 判断创建用户的Id是否和当前请求的用户id是否相同
        IPage<BillUserVo> page = baseMapper.selectListByPage(pageParams, dto, userId);

        return PageResult.<BillUserVo>builder()
                .list(page.getRecords())
                .pageNo(page.getCurrent())
                .pageSize(page.getSize())
                .total(page.getTotal())
                .build();
    }

    /**
     * 添加账单信息
     *
     * @param dto 账单信息添加
     */
    @Override
    public void addBill(@Valid BillUserAddDto dto) {
        // 保存数据
        Bill bill = new Bill();
        BeanUtils.copyProperties(dto, bill);
        save(bill);
    }

    /**
     * 更新账单信息
     *
     * @param dto 账单信息更新
     */
    @Override
    public void updateBill(@Valid BillUserUpdateDto dto) {
        // 更新内容
        Bill bill = new Bill();
        BeanUtils.copyProperties(dto, bill);
        updateById(bill);
    }

    /**
     * 删除|批量删除账单信息
     *
     * @param ids 删除id列表
     */
    @Override
    public void deleteBill(List<Long> ids) {
        baseMapper.deleteBatchIdsWithPhysics(ids);
    }
}
